@@ -49,11 +49,11 @@ class TestWorkbookParser:
         archive.writestr(ARC_WORKBOOK_RELS, b"<root />")
 
         parser = WorkbookParser(archive, ARC_WORKBOOK)
-        assert parser.wb.excel_base_date == CALENDAR_WINDOWS_1900
+        assert parser.wb.epoch == CALENDAR_WINDOWS_1900
 
         parser.parse()
         assert parser.wb.code_name is None
-        assert parser.wb.excel_base_date == CALENDAR_MAC_1904
+        assert parser.wb.epoch == CALENDAR_MAC_1904
 
 
     def test_find_sheets(self, datadir, WorkbookParser):
@@ -136,7 +136,7 @@ class TestWorkbookParser:
         archive = ZipFile("pivot.xlsx")
         parser = WorkbookParser(archive, ARC_WORKBOOK)
         parser.parse()
-        assert list(parser.pivot_caches.keys()) == [68]
+        assert list(parser.pivot_caches) == [68]
 
 
     def test_book_views(self, datadir, WorkbookParser):
