@@ -1,12 +1,12 @@
 from __future__ import absolute_import
-# Copyright (c) 2010-2017 openpyxl
+# Copyright (c) 2010-2018 openpyxl
 
 """Workbook is the top-level container for all document information."""
 
 from openpyxl.compat import deprecated
-from openpyxl.compat import OrderedDict
 from openpyxl.worksheet import Worksheet
 from openpyxl.worksheet.read_only import ReadOnlyWorksheet
+from openpyxl.worksheet.write_only import WriteOnlyWorksheet
 from openpyxl.worksheet.copier import WorksheetCopy
 
 from openpyxl.utils import quote_sheetname
@@ -14,8 +14,7 @@ from openpyxl.utils.indexed_list import IndexedList
 from openpyxl.utils.datetime  import CALENDAR_WINDOWS_1900
 from openpyxl.utils.exceptions import ReadOnlyWorkbookException
 
-from openpyxl.writer.write_only import WriteOnlyWorksheet, save_dump
-from openpyxl.writer.excel import save_workbook
+from openpyxl.writer.excel import save_workbook, save_dump
 
 from openpyxl.styles.cell_style import StyleArray
 from openpyxl.styles.named_styles import NamedStyle
@@ -34,6 +33,9 @@ from .defined_name import DefinedName, DefinedNameList
 from openpyxl.packaging.core import DocumentProperties
 from openpyxl.packaging.relationship import RelationshipList
 from .protection import DocumentSecurity
+from .properties import CalcProperties
+from .views import BookView
+
 
 from openpyxl.xml.constants import (
     XLSM,
@@ -54,8 +56,10 @@ class Workbook(object):
 
     def __init__(self,
                  write_only=False,
+                 iso_dates=False,
                  ):
         self._sheets = []
+        self._pivots = []
         self._active_sheet_index = 0
         self.defined_names = DefinedNameList()
         self._external_links = []
@@ -71,13 +75,16 @@ class Workbook(object):
         self.is_template = False
         self._differential_styles = DifferentialStyleList()
         self.code_name = None
-        self.excel_base_date = CALENDAR_WINDOWS_1900
+        self.epoch = CALENDAR_WINDOWS_1900
         self.encoding = "utf-8"
+        self.iso_dates = iso_dates
 
         if not self.write_only:
             self._sheets.append(Worksheet(self))
 
         self.rels = RelationshipList()
+        self.calculation = CalcProperties()
+        self.views = [BookView()]
 
 
     def _setup_styles(self):
@@ -127,9 +134,17 @@ class Workbook(object):
         """Returns the current active sheet."""
         return self.active
 
+
+    @property
+    def excel_base_date(self):
+        return self.epoch
+
     @property
     def active(self):
-        """Get the currently active sheet or None"""
+        """Get the currently active sheet or None
+
+        :type: :class:`openpyxl.worksheet.worksheet.Worksheet`
+        """
         try:
             return self._sheets[self._active_sheet_index]
         except IndexError:
@@ -144,7 +159,7 @@ class Workbook(object):
         """Create a worksheet (at an optional index).
 
         :param title: optional title of the sheet
-        :type tile: unicode
+        :type title: unicode
         :param index: optional position at which the sheet will be inserted
         :type index: int
 
@@ -177,13 +192,17 @@ class Workbook(object):
 
 
     def remove(self, worksheet):
-        """Remove a worksheet from this workbook."""
+        """Remove `worksheet` from this workbook."""
+        idx = self._sheets.index(worksheet)
+        localnames = self.defined_names.localnames(scope=idx)
+        for name in localnames:
+            self.defined_names.delete(name, scope=idx)
         self._sheets.remove(worksheet)
 
 
     @deprecated("Use wb.remove(worksheet) or del wb[sheetname]")
     def remove_sheet(self, worksheet):
-        """Remove a worksheet from this workbook."""
+        """Remove `worksheet` from this workbook."""
         self.remove(worksheet)
 
 
@@ -227,7 +246,7 @@ class Workbook(object):
         :type name: string
 
         """
-        for sheet in self.worksheets:
+        for sheet in self.worksheets + self.chartsheets:
             if sheet.title == key:
                 return sheet
         raise KeyError("Worksheet {0} does not exist.".format(key))
@@ -246,19 +265,27 @@ class Workbook(object):
 
     @property
     def worksheets(self):
+        """A list of sheets in this workbook
+
+        :type: list of :class:`openpyxl.worksheet.worksheet.Worksheet`
+        """
         return [s for s in self._sheets if isinstance(s, (Worksheet, ReadOnlyWorksheet, WriteOnlyWorksheet))]
 
     @property
     def chartsheets(self):
+        """A list of Chartsheets in this workbook
+
+        :type: list of :class:`openpyxl.chartsheet.chartsheet.Chartsheet`
+        """
         return [s for s in self._sheets if isinstance(s, Chartsheet)]
 
     @property
     def sheetnames(self):
-        """Returns the list of the names of worksheets in the workbook.
+        """Returns the list of the names of worksheets in this workbook.
 
         Names are returned in the worksheets order.
 
-        :rtype: list of strings
+        :type: list of strings
 
         """
         return [s.title for s in self._sheets]
@@ -355,8 +382,10 @@ class Workbook(object):
 
     def copy_worksheet(self, from_worksheet):
         """Copy an existing worksheet in the current workbook
-        :warning: This function cannot copy worksheets between workbooks.
-        worksheets can only be copied within the workbook that they belong
+
+        .. warning::
+            This function cannot copy worksheets between workbooks.
+            worksheets can only be copied within the workbook that they belong
 
         :param from_worksheet: the worksheet to be copied from
         :return: copy of the initial worksheet
